# curvewalk

[![Test Code](https://github.com/mark-goodall/curvewalk/actions/workflows/test.yml/badge.svg)](https://github.com/mark-goodall/curvewalk/actions/workflows/test.yml)
[![Docs](https://app.readthedocs.org/projects/curvewalk/badge/?version=latest)](https://curvewalk.readthedocs.io/en/latest/)

A straightforward implementation of space filling curves over an array or fixed size.

## Supported curves

* Lawnmower or Boustrophedon over arbitrary array sizes and dimensions.
* Hilbert curve over 2d square power of two arrays.
* Z-curve (Morton order) over any dimension power of two arrays.
